Changelog
=========

0.0.3 (2020-05-13)
------------------

- fixed how `wai.tfutils.load_labels` determines maximum number of classes


0.0.2 (2020-05-12)
------------------

- `wai.tfutils.load_labels` can determine maximum number of classes to use now
  directly from the label protobuf file (if not provided)


0.0.1 (2020-01-22)
------------------

- initial release
